==> jk_prettyprintobj-0.2024.10.20-py3-none-any.whl: jk_prettyprintobj/RawValue.py <==



#
# Represents a value that should be written directly without any automatic formatting.
#
class RawValue(object):

	################################################################################################################################
	## Constants
	################################################################################################################################

	################################################################################################################################
	## Constructor
	################################################################################################################################

	#
	# Constructor method.
	#
	def __init__(self, text:str) -> None:
		assert isinstance(text, str)
		assert text

		self.text = text
	#

	################################################################################################################################
	## Public Properties
	################################################################################################################################

	################################################################################################################################
	## Helper Methods
	################################################################################################################################

	################################################################################################################################
	## Public Methods
	################################################################################################################################

	################################################################################################################################
	## Public Static Methods
	################################################################################################################################

#

==> jk_prettyprintobj-0.2025.5.24-py3-none-any.whl: jk_prettyprintobj/RawValue.py <==


import typing





#
# Represents a value that should be written directly without any automatic formatting.
#
class RawValue(object):

	################################################################################################################################
	## Constants
	################################################################################################################################

	################################################################################################################################
	## Constructor
	################################################################################################################################

	#
	# Constructor method.
	#
	def __init__(self, textOrLines:typing.Union[str,typing.List[str],typing.Tuple[str]]) -> None:
		assert isinstance(textOrLines, (str,tuple,list))
		assert textOrLines

		self.textOrLines = textOrLines
	#

	################################################################################################################################
	## Public Properties
	################################################################################################################################

	################################################################################################################################
	## Helper Methods
	################################################################################################################################

	################################################################################################################################
	## Public Methods
	################################################################################################################################

	################################################################################################################################
	## Public Static Methods
	################################################################################################################################

#
